@@ -1,4 +1,6 @@
 """Tests for PyGeoUtils"""
+import io
+
 import pytest
 from pygeoogc import WFS, WMS
 from shapely.geometry import Polygon
@@ -29,6 +31,7 @@ def geometry_urb():
     )
 
 
+@pytest.mark.flaky(max_runs=3)
 def test_gtiff2array(geometry_nat):
     url_wms = "https://www.fws.gov/wetlands/arcgis/services/Wetlands_Raster/ImageServer/WMSServer"
     wms = WMS(url_wms, layers="0", outformat="image/tiff", crs="epsg:3857",)
@@ -39,6 +42,7 @@ def test_gtiff2array(geometry_nat):
     assert abs(wetlands.isel(band=0).mean().values.item() - 16.542) < 1e-3
 
 
+@pytest.mark.flaky(max_runs=3)
 def test_json2geodf(geometry_urb):
     url_wfs = "https://hazards.fema.gov/gis/nfhl/services/public/NFHL/MapServer/WFSServer"
 
@@ -161,3 +165,9 @@ def test_matchcrs(geometry_urb):
         and abs(bbox[0] - (-3654031.190)) < 1e-3
         and abs(coords[0][-1] == (-2877067.244)) < 1e-3
     )
+
+
+def test_show_versions():
+    f = io.StringIO()
+    geoutils.show_versions(file=f)
+    assert "INSTALLED VERSIONS" in f.getvalue()
